/// <reference types="@types/amap-js-api" />
import { OnDestroy, EventEmitter, SimpleChanges, OnChanges, QueryList, AfterContentInit, ElementRef, NgZone } from '@angular/core';
import { AmapTextService } from './amap-text.service';
import { LoggerService } from '../../shared/logger/logger.service';
import { AMapOverlay } from '../../base/amap-overlay';
import { EventBinderService } from '../../shared/event-binder.service';
import { IPixel, IIcon } from '../../interfaces';
import { PixelService } from '../../shared/pixel.service';
import { IconService } from '../../shared/icon.service';
import { AmapInfoWindowComponent } from '../amap-info-window/amap-info-window.component';
import { AMapService } from '../../shared/amap.service';
export declare class AmapTextComponent extends AMapOverlay<AMap.Text> implements OnChanges, OnDestroy, AfterContentInit {
    protected os: AmapTextService;
    protected binder: EventBinderService;
    private amaps;
    private el;
    private pixels;
    private icons;
    private logger;
    private ngZone;
    /**
     * 点标记显示内容
     */
    text: string;
    /**
     * 点标记在地图上显示的位置
     */
    position: AMap.LocationValue;
    /**
     * 标记锚点
     */
    anchor: AMap.Marker.Anchor;
    /**
     * 点标记显示位置偏移量
     */
    offset: AMap.Pixel | IPixel;
    /**
     * 鼠标点击时marker是否置顶
     */
    topWhenClick: boolean;
    /**
     * 拖拽点标记时是否开启点标记离开地图的效果
     */
    raiseOnDrag: boolean;
    /**
     * 点标记是否可见
     */
    visible: boolean;
    /**
     * 点标记的叠加顺序
     */
    zIndex: number;
    /**
     * 点标记的旋转角度
     */
    angle: number;
    /**
     * 是否自动旋转
     */
    autoRotation: boolean;
    /**
     * 点标记的动画效果
     */
    animation: AMap.AnimationName;
    /**
     * 点标记阴影
     */
    shadow: AMap.Icon | string | IIcon;
    /**
     * 鼠标滑过点标记时的文字提示
     */
    title: string;
    /**
     * 样式
     */
    style: {
        [key: string]: string;
    };
    /**
     * 额外: 是否置顶
     */
    isTop: boolean;
    /**
     * 额外: 是否隐藏
     */
    hidden: boolean;
    /**
     * 额外: 是否包含在点聚合中
     */
    inCluster: boolean;
    /**
     * 额外: 点击时是否显示信息窗体
     */
    openInfoWindow: boolean;
    naReady: EventEmitter<any>;
    naMouseOut: EventEmitter<any>;
    naDragStart: EventEmitter<any>;
    naDragging: EventEmitter<any>;
    naDragEnd: EventEmitter<any>;
    naMoving: EventEmitter<any>;
    naMoveEnd: EventEmitter<any>;
    naMoveAlong: EventEmitter<any>;
    infoWindowComponent: QueryList<AmapInfoWindowComponent>;
    private inited;
    private subscription;
    constructor(os: AmapTextService, binder: EventBinderService, amaps: AMapService, el: ElementRef, pixels: PixelService, icons: IconService, logger: LoggerService, ngZone: NgZone);
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterContentInit(): void;
    private updateInfoWindow;
    private updateInfoWindowPosition;
    /**
     * 获取已创建的 AMap.Text 对象
     */
    get(): import("rxjs").Observable<AMap.Text<any>>;
}
