import { NgZone } from '@angular/core';
import { AMapService } from '../../shared/amap.service';
import { PluginLoaderService } from '../../shared/plugin-loader.service';
import { LoggerService } from '../../shared/logger/logger.service';
import { Getter } from '../../base/interfaces';
export declare namespace AMapHeatmap {
    interface Options {
        /**
         * 热力图中单个点的半径，默认：30，单位：pixel
         */
        radius?: number;
        /**
         * 热力图的渐变区间
         */
        gradient?: {
            [key: string]: string;
        };
        /**
         * 热力图透明度数组，取值范围[0,1]，0表示完全透明，1表示不透明
         * 默认：[0,1]
         */
        opacity?: [number, number];
        /**
         * 支持的缩放级别范围，取值范围[3-18]
         * 默认：[3,18]
         */
        zooms?: [number, number];
        rejectMapMask?: boolean;
        visible?: boolean;
        radiusUnit?: string;
        blur?: number;
        zIndex?: number;
        renderOnZooming?: boolean;
        ['3d']?: {
            heightScale?: number;
            heightBezier?: number[];
            gridSize?: number;
            drawGridLine?: boolean;
        };
    }
    interface Data {
        /**
         * 经度
         */
        lng: number;
        /**
         * 维度
         */
        lat: number;
        /**
         * 权重
         */
        count: number;
    }
    interface DataSet {
        /**
         * 权重的最大值
         */
        max?: number;
        /**
         * 坐标数据集
         */
        data: Data[];
    }
}
export declare class AmapHeatmapService implements Getter<any> {
    private amaps;
    private plugin;
    private logger;
    private ngZone;
    private heatmap;
    private heatmap$;
    constructor(amaps: AMapService, plugin: PluginLoaderService, logger: LoggerService, ngZone: NgZone);
    /**
     * 获取热力图
     */
    get(): import("rxjs").Observable<any>;
    /**
     * 创建热力图 AMap.Heatmap
     * @param options 选项
     */
    create(options: AMapHeatmap.Options): import("rxjs").Observable<any>;
    /**
     * 销毁热力图
     */
    destroy(): void;
}
