/// <reference types="@types/amap-js-api" />
import { OnInit, OnDestroy, EventEmitter, SimpleChanges, OnChanges, NgZone } from '@angular/core';
import { AmapToolBarService, AMapToolBar } from './amap-tool-bar.service';
import { LoggerService } from '../../shared/logger/logger.service';
import { EventBinderService } from '../../shared/event-binder.service';
import { IPixel } from '../../interfaces';
import { PixelService } from '../../shared/pixel.service';
import { AMapService } from '../../shared/amap.service';
export declare class AmapToolBarDirective implements OnInit, OnChanges, OnDestroy {
    protected os: AmapToolBarService;
    protected binder: EventBinderService;
    private amaps;
    private pixels;
    private logger;
    private ngZone;
    /**
     * 相对于地图容器左上角的偏移量
     */
    offset: AMap.Pixel | IPixel;
    /**
     * 控件停靠位置
     * LT: 左上角
     * RT: 右上角
     * LB: 左下角
     * RB: 右下角
     */
    position: AMapToolBar.Position;
    /**
     * 标尺键盘是否可见
     */
    ruler: boolean;
    /**
     * 定位失败后，是否开启 IP 定位
     */
    noIpLocate: boolean;
    /**
     * 是否显示定位按钮
     */
    locate: boolean;
    /**
     * 是否使用精简模式
     */
    liteStyle: boolean;
    /**
     * 方向键盘是否可见
     */
    direction: boolean;
    /**
     * 是否自动定位，即地图初始化加载完成后，是否自动定位的用户所在地，仅在支持 HTML5 的浏览器中有效
     */
    autoPosition: boolean;
    /**
     * 自定义定位图标，值为 Marker 对象
     */
    locationMarker: AMap.Marker;
    /**
     * 是否使用高德定位 SDK 用来辅助优化定位效果
     */
    useNative: boolean;
    /**
     * 额外: 是否隐藏
     */
    hidden: boolean;
    naReady: EventEmitter<any>;
    naShow: EventEmitter<any>;
    naHide: EventEmitter<any>;
    naLocation: EventEmitter<any>;
    naZoomChanged: EventEmitter<any>;
    private inited;
    constructor(os: AmapToolBarService, binder: EventBinderService, amaps: AMapService, pixels: PixelService, logger: LoggerService, ngZone: NgZone);
    ngOnDestroy(): void;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * 获取已创建的 AMap.ToolBar 对象
     */
    get(): import("rxjs").Observable<any>;
    doLocation(): void;
}
